# hurst_pipeline

installation: pip install neuroHurst

usage: neuroHurst <bids_directory> <output_directory> participant <source_format>

example: neuroHurst /project2/bermanm/ABCD/preproccessed_data/ /project2/bermanm/ABCD/preproccessed_data/derivatives participant bold
